searchData={"items":[{"type":"module","title":"Secp256k1","doc":"This is unified API for all secp256k1 functions this library provides","ref":"Secp256k1.html"},{"type":"module","title":"Examples - Secp256k1","doc":"","ref":"Secp256k1.html#module-examples"},{"type":"module","title":"Generate new keypair - Secp256k1","doc":"iex> {_seckey, _pubkey} = Secp256k1.keypair(:xonly)","ref":"Secp256k1.html#module-generate-new-keypair"},{"type":"module","title":"Derive pubkey from your awesome seckey - Secp256k1","doc":"iex> seckey = <<0x1111111111111111111111111111111111111111111111111111111111111111::256>>\n    iex> pubkey = Secp256k1.pubkey(seckey, :compressed)\n    iex> Base.encode16(pubkey, case: :lower)\n    \"034f355bdcb7cc0af728ef3cceb9615d90684bb5b2ca5f859ab0f0b704075871aa\"","ref":"Secp256k1.html#module-derive-pubkey-from-your-awesome-seckey"},{"type":"module","title":"Calculate ECDSA signature - Secp256k1","doc":"iex> # your keypair\n    iex> {seckey, pubkey} = Secp256k1.keypair(:compressed)\n    iex> # prepare your message hash\n    iex> msg_hash = :crypto.hash(:sha256, \"My awesome message\")\n    iex> # generate signature\n    iex> sig = Secp256k1.ecdsa_sign(msg_hash, seckey)\n    iex> # validate your signature\n    iex> Secp256k1.ecdsa_valid?(sig, msg_hash, pubkey)\n    true","ref":"Secp256k1.html#module-calculate-ecdsa-signature"},{"type":"module","title":"Calculate Schnorr signature - Secp256k1","doc":"iex> # your keypair\n    iex> {seckey, pubkey} = Secp256k1.keypair(:xonly)\n    iex> # prepare your message hash\n    iex> msg_hash = :crypto.hash(:sha256, \"My awesome message\")\n    iex> # generate signature\n    iex> sig = Secp256k1.schnorr_sign(msg_hash, seckey)\n    iex> # validate your signature\n    iex> Secp256k1.schnorr_valid?(sig, msg_hash, pubkey)\n    true","ref":"Secp256k1.html#module-calculate-schnorr-signature"},{"type":"type","title":"Secp256k1.compressed_pubkey/0","doc":"Compressed pubkey is binary of 33 byte length","ref":"Secp256k1.html#t:compressed_pubkey/0"},{"type":"type","title":"Secp256k1.ecdsa_sig/0","doc":"Serialized compressed ECDSA signature is 64 bytes long binary","ref":"Secp256k1.html#t:ecdsa_sig/0"},{"type":"function","title":"Secp256k1.ecdsa_sign/2","doc":"Create an ECDSA signature\n\nInputs\n  - `msg_hash` 32 byte long message hash to sign\n  - `seckey` 32 byte long binary\n\nOutput\n  - `signature` ECDSA signature serialized in compressed format (64 byte binary)","ref":"Secp256k1.html#ecdsa_sign/2"},{"type":"function","title":"Secp256k1.ecdsa_valid?/3","doc":"Validate ECDSA signature\n\nInputs\n  - `signature` 64 byte long binary\n  - `msg_hash` 32 byte long message hash that was signed\n  - `pubkey` compressed pubkey (33 byte long binary)","ref":"Secp256k1.html#ecdsa_valid?/3"},{"type":"type","title":"Secp256k1.hash/0","doc":"Hash is 32 bytes long binary","ref":"Secp256k1.html#t:hash/0"},{"type":"function","title":"Secp256k1.keypair/1","doc":"Generate new secp256k1 keypair\n\nInput\n  - `type` (see `pubkey/2`)\n\nOutput\n  - 2-tuple with seckey on the first place and pubkey on the second place","ref":"Secp256k1.html#keypair/1"},{"type":"function","title":"Secp256k1.keypair/2","doc":"Generate new secp256k1 keypair from provided seckey\n\nFor options see `pubkey/2`","ref":"Secp256k1.html#keypair/2"},{"type":"type","title":"Secp256k1.pubkey/0","doc":"Pubkey is binary of 32, 33 or 65 byte length","ref":"Secp256k1.html#t:pubkey/0"},{"type":"function","title":"Secp256k1.pubkey/2","doc":"Derive pubkey from provided seckey\n\nInputs\n  - `seckey` 32 byte long binary\n  - `type` one of `:xonly`, `:compressed` or `:uncompressed`\n\nOutput\n  - `pubkey` serialization type depends on the type provided","ref":"Secp256k1.html#pubkey/2"},{"type":"type","title":"Secp256k1.pubkey_type/0","doc":"Pubkey can be parsed in compressed (33 bytes), uncompressed (65 bytes) or xonly (32 bytes) format","ref":"Secp256k1.html#t:pubkey_type/0"},{"type":"type","title":"Secp256k1.schnorr_sig/0","doc":"Schnorr signature is 64 bytes long binary","ref":"Secp256k1.html#t:schnorr_sig/0"},{"type":"function","title":"Secp256k1.schnorr_sign/2","doc":"Calculate Schnorr signature according to BIP 340\n\nInputs\n  - `message` can accept arbitrary long binary but only 32 byte long hash is the only option\n    strictly according to specification\n  - `seckey` 32 byte long binary\n\nOutput\n  - `signature` Schnorr signature is 64 byte long binary\n\n_Note:_ automatic random nonce is added to every run so generated signature is not deterministic","ref":"Secp256k1.html#schnorr_sign/2"},{"type":"function","title":"Secp256k1.schnorr_valid?/3","doc":"Validate Schnorr signature\n\nInputs\n  - `signature` 64 byte long binary\n  - `message` arbitrary long binary\n  - `pubkey` xonly pubkey (32 byte long binary)","ref":"Secp256k1.html#schnorr_valid?/3"},{"type":"type","title":"Secp256k1.seckey/0","doc":"EC secp256k1 seckey is 32 bytes long binary","ref":"Secp256k1.html#t:seckey/0"},{"type":"type","title":"Secp256k1.shared_secret/0","doc":"ECDH shared secret is 32 bytes long binary","ref":"Secp256k1.html#t:shared_secret/0"},{"type":"type","title":"Secp256k1.uncompressed_pubkey/0","doc":"Uncompressed pubkey is binary of 65 byte length","ref":"Secp256k1.html#t:uncompressed_pubkey/0"},{"type":"type","title":"Secp256k1.xonly_pubkey/0","doc":"X-only pubkey is binary of 32 byte length","ref":"Secp256k1.html#t:xonly_pubkey/0"},{"type":"module","title":"Secp256k1.Guards","doc":"Common guards for secp256k1 functions","ref":"Secp256k1.Guards.html"},{"type":"macro","title":"Secp256k1.Guards.is_bin_size/2","doc":"Is binary of specific size","ref":"Secp256k1.Guards.html#is_bin_size/2"},{"type":"macro","title":"Secp256k1.Guards.is_compressed_pubkey/1","doc":"Is compressed pubkey (probably) - binary 33 bytes long","ref":"Secp256k1.Guards.html#is_compressed_pubkey/1"},{"type":"macro","title":"Secp256k1.Guards.is_ecdsa_sig/1","doc":"Is ECDSA signature (probably) - binary 64 bytes long","ref":"Secp256k1.Guards.html#is_ecdsa_sig/1"},{"type":"macro","title":"Secp256k1.Guards.is_hash/1","doc":"Is hash (probably) - binary 32 bytes long","ref":"Secp256k1.Guards.html#is_hash/1"},{"type":"macro","title":"Secp256k1.Guards.is_pubkey/1","doc":"Is any type of pubkey (probably)","ref":"Secp256k1.Guards.html#is_pubkey/1"},{"type":"macro","title":"Secp256k1.Guards.is_schnorr_sig/1","doc":"Is Schnorr signature (probably) - binary 64 bytes long","ref":"Secp256k1.Guards.html#is_schnorr_sig/1"},{"type":"macro","title":"Secp256k1.Guards.is_seckey/1","doc":"Is seckey (probably) - binary 32 bytes long","ref":"Secp256k1.Guards.html#is_seckey/1"},{"type":"macro","title":"Secp256k1.Guards.is_uncompressed_pubkey/1","doc":"Is uncompressed pubkey (probably) - binary 65 bytes long","ref":"Secp256k1.Guards.html#is_uncompressed_pubkey/1"},{"type":"macro","title":"Secp256k1.Guards.is_xonly_pubkey/1","doc":"Is xonly pubkey (probably) - binary 32 bytes long","ref":"Secp256k1.Guards.html#is_xonly_pubkey/1"},{"type":"module","title":"Secp256k1.ECDSA","doc":"Module implementing ECDSA pubkey derivation and signatures","ref":"Secp256k1.ECDSA.html"},{"type":"function","title":"Secp256k1.ECDSA.compress_pubkey/1","doc":"Convert uncompressed pubkey to compressed one","ref":"Secp256k1.ECDSA.html#compress_pubkey/1"},{"type":"function","title":"Secp256k1.ECDSA.compressed_pubkey/1","doc":"Derive compressed pubkey from seckey","ref":"Secp256k1.ECDSA.html#compressed_pubkey/1"},{"type":"function","title":"Secp256k1.ECDSA.decompress_pubkey/1","doc":"Convert compressed pubkey to uncompressed one","ref":"Secp256k1.ECDSA.html#decompress_pubkey/1"},{"type":"function","title":"Secp256k1.ECDSA.pubkey/2","doc":"Derive pubkey from seckey","ref":"Secp256k1.ECDSA.html#pubkey/2"},{"type":"function","title":"Options - Secp256k1.ECDSA.pubkey/2","doc":"- :compress (default true) - whether to format pubkey in compressed or uncompressed format","ref":"Secp256k1.ECDSA.html#pubkey/2-options"},{"type":"function","title":"Secp256k1.ECDSA.sign/2","doc":"Generate ECDSA signature of message hash (AUX is randomly generated)","ref":"Secp256k1.ECDSA.html#sign/2"},{"type":"function","title":"Secp256k1.ECDSA.sign/3","doc":"Generate ECDSA signature of message hash and specify AUX value - NOT RECOMMENDED","ref":"Secp256k1.ECDSA.html#sign/3"},{"type":"function","title":"Secp256k1.ECDSA.uncompressed_pubkey/1","doc":"Derive uncompressed pubkey from seckey","ref":"Secp256k1.ECDSA.html#uncompressed_pubkey/1"},{"type":"function","title":"Secp256k1.ECDSA.valid?/3","doc":"Check if ECDSA signature is valid","ref":"Secp256k1.ECDSA.html#valid?/3"},{"type":"module","title":"Secp256k1.Extrakeys","doc":"Module implementing extrakeys functions of secp256k1","ref":"Secp256k1.Extrakeys.html"},{"type":"function","title":"Secp256k1.Extrakeys.xonly_pubkey/1","doc":"Derive xonly pubkey from seckey","ref":"Secp256k1.Extrakeys.html#xonly_pubkey/1"},{"type":"module","title":"Secp256k1.Schnorr","doc":"Module implementing Schnorr signatures as defined in BIP340","ref":"Secp256k1.Schnorr.html"},{"type":"function","title":"Secp256k1.Schnorr.sign32/2","doc":"Generate Schnorr signature of a hash (AUX is randomly generated)","ref":"Secp256k1.Schnorr.html#sign32/2"},{"type":"function","title":"Secp256k1.Schnorr.sign32/3","doc":"Generate Schnorr signature of a hash and specify AUX - NOT RECOMMENDED","ref":"Secp256k1.Schnorr.html#sign32/3"},{"type":"function","title":"Secp256k1.Schnorr.sign/2","doc":"Generate Schnorr signature of message (can be hash or custom length message)","ref":"Secp256k1.Schnorr.html#sign/2"},{"type":"function","title":"Secp256k1.Schnorr.sign_custom/2","doc":"Generate Schnorr signature of arbitrary message (AUX is randomly generated)","ref":"Secp256k1.Schnorr.html#sign_custom/2"},{"type":"function","title":"Secp256k1.Schnorr.sign_custom/3","doc":"Generate Schnorr signature of a arbitrary message and specify AUX - NOT RECOMMENDED","ref":"Secp256k1.Schnorr.html#sign_custom/3"},{"type":"function","title":"Secp256k1.Schnorr.valid?/3","doc":"Validate Schnorr signature","ref":"Secp256k1.Schnorr.html#valid?/3"},{"type":"extras","title":"Overview","doc":"# Secp256k1 library\n\n[![Hex.pm](https://img.shields.io/hexpm/v/lib_secp256k1.svg?style=flat&color=blue)](https://hex.pm/packages/lib_secp256k1)\n[![Docs](https://img.shields.io/badge/api-docs-green.svg?style=flat)](https://hexdocs.pm/lib_secp256k1)\n\nElixir bindings for the [secp256k1](https://github.com/bitcoin-core/secp256k1) cryptographic\nlibrary, used extensively in blockchain and cryptocurrency applications.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"Add `lib_secp256k1` to your project's dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:lib_secp256k1, \"~> 0.6.0\"},\n  ]\nend\n```\n\nThe underlying C library and Elixir bindings are compiled automatically during the installation.\nIf you encounter issues during compilation, please check the original secp256k1 repository.\n\nCurrently, compilation is tested primarily on Linux. If you experience issues on macOS or Windows,\nplease open an issue—although immediate support for these platforms is limited, contributions are\nalways welcome.","ref":"readme.html#installation"},{"type":"extras","title":"MacOS - Overview","doc":"You may need to install additional dependencies via Homebrew:\n\n```\nbrew install make gcc autoconf autobuild\n```","ref":"readme.html#macos"},{"type":"extras","title":"Features - Overview","doc":"- [x] generate secure random seckey\n- [x] derive pubkey and serialize it in compressed, uncompressed or xonly format\n- [x] generate and validate ECDSA signatures\n- [x] generate and validate Schnorr signatures\n- [x] compute Diffie-Hellman secret","ref":"readme.html#features"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.6.1 (2025-03-31) - Changelog","doc":"- Update dependencies\n- Fix LDFLAGS on MacOS","ref":"changelog.html#v0-6-1-2025-03-31"},{"type":"extras","title":"v0.6.0 (2024-11-08) - Changelog","doc":"- Upgrade lib to version v0.6.0","ref":"changelog.html#v0-6-0-2024-11-08"},{"type":"extras","title":"v0.5.1 (2024-10-21) - Changelog","doc":"- Upgrade lib to version v0.5.1","ref":"changelog.html#v0-5-1-2024-10-21"},{"type":"extras","title":"v0.5.0 (2024-10-20) - Changelog","doc":"- Upgrade lib to version v0.5.0","ref":"changelog.html#v0-5-0-2024-10-20"},{"type":"extras","title":"v0.4.1 (2023-12-29) - Changelog","doc":"- Upgrade lib to version v0.4.1","ref":"changelog.html#v0-4-1-2023-12-29"},{"type":"extras","title":"v0.4.0 (2023-09-05) - Changelog","doc":"- Upgrade lib to version v0.4.0","ref":"changelog.html#v0-4-0-2023-09-05"},{"type":"extras","title":"v0.3.3 (2023-06-07) - Changelog","doc":"- Fixed issue with library name","ref":"changelog.html#v0-3-3-2023-06-07"},{"type":"extras","title":"RETIRED! v0.3.2 (2023-06-07) - Changelog","doc":"- Initial release on hex.pm","ref":"changelog.html#retired-v0-3-2-2023-06-07"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}