searchNodes=[{"type":"module","title":"Secp256k1","doc":"This is unified API for all secp256k1 functions this library provides Examples Generate new keypair iex&gt; { _seckey , _pubkey } = Secp256k1 . keypair ( :xonly ) Derive pubkey from your awesome seckey iex&gt; seckey = &lt;&lt; 0x1111111111111111111111111111111111111111111111111111111111111111 :: 256 &gt;&gt; iex&gt; pubkey = Secp256k1 . pubkey ( seckey , :compressed ) iex&gt; Base . encode16 ( pubkey , case : :lower ) &quot;034f355bdcb7cc0af728ef3cceb9615d90684bb5b2ca5f859ab0f0b704075871aa&quot; Calculate ECDSA signature iex&gt; # your keypair iex&gt; { seckey , pubkey } = Secp256k1 . keypair ( :compressed ) iex&gt; # prepare your message hash iex&gt; msg_hash = :crypto . hash ( :sha256 , &quot;My awesome message&quot; ) iex&gt; # generate signature iex&gt; sig = Secp256k1 . ecdsa_sign ( msg_hash , seckey ) iex&gt; # validate your signature iex&gt; Secp256k1 . ecdsa_valid? ( sig , msg_hash , pubkey ) true Calculate Schnorr signature iex&gt; # your keypair iex&gt; { seckey , pubkey } = Secp256k1 . keypair ( :xonly ) iex&gt; # prepare your message hash iex&gt; msg_hash = :crypto . hash ( :sha256 , &quot;My awesome message&quot; ) iex&gt; # generate signature iex&gt; sig = Secp256k1 . schnorr_sign ( msg_hash , seckey ) iex&gt; # validate your signature iex&gt; Secp256k1 . schnorr_valid? ( sig , msg_hash , pubkey ) true","ref":"Secp256k1.html"},{"type":"function","title":"Secp256k1.ecdsa_sign/2","doc":"Create an ECDSA signature Inputs msg_hash 32 byte long message hash to sign seckey 32 byte long binary Output signature ECDSA signature serialized in compressed format (64 byte binary)","ref":"Secp256k1.html#ecdsa_sign/2"},{"type":"function","title":"Secp256k1.ecdsa_valid?/3","doc":"Validate ECDSA signature Inputs signature 64 byte long binary msg_hash 32 byte long message hash to sign pubkey compressed pubkey (33 byte long binary)","ref":"Secp256k1.html#ecdsa_valid?/3"},{"type":"function","title":"Secp256k1.keypair/1","doc":"Generate new secp256k1 keypair Input type (see pubkey/2 ) Output 2-tuple with seckey on the first place and pubkey on the second place","ref":"Secp256k1.html#keypair/1"},{"type":"function","title":"Secp256k1.keypair/2","doc":"Generate new secp256k1 keypair from provided seckey For options see pubkey/2","ref":"Secp256k1.html#keypair/2"},{"type":"function","title":"Secp256k1.pubkey/2","doc":"Derive pubkey from provided seckey Inputs seckey 32 byte long binary type one of :xonly , :compressed or :uncompressed Output pubkey serialization type depends on the type provided","ref":"Secp256k1.html#pubkey/2"},{"type":"function","title":"Secp256k1.schnorr_sign/2","doc":"Calculate Schnorr signature according to BIP 340 Inputs message can accept arbitrary long binary but only 32 byte long hash is the only option strictly according to specification seckey 32 byte long binary Output signature Schnorr signature is 64 byte long binary Note: automatic random nonce is added to every run so generated signature is not deterministic","ref":"Secp256k1.html#schnorr_sign/2"},{"type":"function","title":"Secp256k1.schnorr_valid?/3","doc":"Validate Schnorr signature Inputs signature 64 byte long binary message arbitrary long binary pubkey xonly pubkey (32 byte long binary)","ref":"Secp256k1.html#schnorr_valid?/3"},{"type":"type","title":"Secp256k1.compressed_pubkey/0","doc":"Compressed pubkey is binary of 33 byte length","ref":"Secp256k1.html#t:compressed_pubkey/0"},{"type":"type","title":"Secp256k1.ecdsa_sig/0","doc":"Serialized compressed ECDSA signature is 64 bytes long binary","ref":"Secp256k1.html#t:ecdsa_sig/0"},{"type":"type","title":"Secp256k1.hash/0","doc":"Hash is 32 bytes long binary","ref":"Secp256k1.html#t:hash/0"},{"type":"type","title":"Secp256k1.pubkey/0","doc":"Pubkey is binary of 32, 33 or 65 byte length","ref":"Secp256k1.html#t:pubkey/0"},{"type":"type","title":"Secp256k1.pubkey_type/0","doc":"Pubkey can be parsed in compressed (33 bytes), uncompressed (65 bytes) or xonly (32 bytes) format","ref":"Secp256k1.html#t:pubkey_type/0"},{"type":"type","title":"Secp256k1.schnorr_sig/0","doc":"Schnorr signature is 64 bytes long binary","ref":"Secp256k1.html#t:schnorr_sig/0"},{"type":"type","title":"Secp256k1.seckey/0","doc":"EC secp256k1 seckey is 32 bytes long binary","ref":"Secp256k1.html#t:seckey/0"},{"type":"type","title":"Secp256k1.shared_secret/0","doc":"ECDH shared secret is 32 bytes long binary","ref":"Secp256k1.html#t:shared_secret/0"},{"type":"type","title":"Secp256k1.uncompressed_pubkey/0","doc":"Uncompressed pubkey is binary of 65 byte length","ref":"Secp256k1.html#t:uncompressed_pubkey/0"},{"type":"type","title":"Secp256k1.xonly_pubkey/0","doc":"X-only pubkey is binary of 32 byte length","ref":"Secp256k1.html#t:xonly_pubkey/0"},{"type":"extras","title":"Overview","doc":"Elixir bindings for secp256k1 library Generated documentation can be found at https://secp256k1.sgiath.dev","ref":"readme.html"},{"type":"extras","title":"Overview - Installation","doc":"The package can be installed by adding secp256k1 to your list of dependencies in mix.exs : def deps do [ { :secp256k1 , github : &quot;Sgiath/secp256k1&quot; } ] end During the compilation the C library is cloned and build from source. If you are having problem compiling the library please refer to the original repository. The C code wrapping the library is also build during the compilation. I only tested it on Linux machine so if you are having problem compiling it on Mac or Windows it is most likely related to that. Please fill an issue but I don't have other systems available to me so don't expect me to fix it anytime soon (contributions are welcome though :) ).","ref":"readme.html#installation"},{"type":"extras","title":"Overview - Features","doc":"[x] generate secure random seckey [x] derive pubkey and serialize it in compressed, uncompressed or xonly format [x] generate and validate ECDSA signatures [x] generate and validate Schnorr signatures [x] compute Diffie-Hellman secret","ref":"readme.html#features"}]